@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0604';
+our $VERSION = '0.0605';
 
 use Moo;
 use strictures 2;
@@ -318,7 +318,7 @@ Music::Bassline::Generator - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0604
+version 0.0605
 
 =head1 SYNOPSIS
 
@@ -524,6 +524,10 @@ Defaults:
 
 =head1 SEE ALSO
 
+Previous versions of this module can be found at
+L<http://backpan.cpantesters.org/authors/id/G/GE/GENE/>,
+named "MIDI::Bassline::Walk."
+
 The F<t/> and F<eg/> programs
 
 L<Data::Dumper::Compact>
